videocollection/videocollectionwrapper/tsrc/testvideocollectionlistener/stub/inc/stubsignalreceiver.h
changeset 55 4bfa887905cf
parent 38 ff53afa8ad05
--- a/videocollection/videocollectionwrapper/tsrc/testvideocollectionlistener/stub/inc/stubsignalreceiver.h	Fri Aug 06 09:43:48 2010 +0300
+++ b/videocollection/videocollectionwrapper/tsrc/testvideocollectionlistener/stub/inc/stubsignalreceiver.h	Mon Aug 23 14:27:29 2010 +0300
@@ -75,9 +75,14 @@
     int getLatestIntegerData();
     
     /**
-     * return mListComplete
+     * return mVideoListComplete
      */
-    bool getListComplete();
+    bool getVideoListComplete();
+    
+    /**
+     * return mAlbumListComplete
+     */
+    bool getAlbumListComplete();
     
 public slots:
 
@@ -120,7 +125,7 @@
      * Saves provided integer to mLatestItemId and provided pointer to
      * mLatestPtr
      */
-    void albumListAvailableSlot(TMPXItemId albumId,
+    void albumListAvailableSlot(TMPXItemId &albumId,
             CMPXMediaArray *albumItems);
     
     /**
@@ -131,7 +136,7 @@
     /**
      * saves provided item id into mLatestItemId
      */
-    void itemDeletedSlot(TMPXItemId id);
+    void itemDeletedSlot(TMPXItemId &id);
     
     /**
      * saves provided item id into mLatestModifiedItemId
@@ -139,9 +144,14 @@
     virtual void itemModifiedSlot(const TMPXItemId &itemId);
     
     /**
-     * Sets boolean mListComplete to true;
+     * Sets boolean mVideoListComplete to true;
      */
-    void listCompleteSlot();
+    void videoListCompleteSlot();
+    
+    /**
+     * Sets boolean mAlbumListcomplete to true;
+     */
+    void albumListCompleteSlot();
     
 private:
     /**
@@ -170,9 +180,14 @@
     QList<TMPXItemId> mLatesListData;
     
     /**
      * True if listCompleteSlot has been called.
      */
-    bool mListComplete;
+    bool mVideoListComplete;
+
+    /**
+     * True if albumListCompleteSlot has been called.
+     */
+    bool mAlbumListComplete;
 };
 
 #endif
@@ -170,9 +180,14 @@
     
     /**
-     * True if listCompleteSlot has been called.
+     * True if videoListCompleteSlot has been called.
      */